Documentation
¶
Index ¶
- func EnsureTargetPID() error
- func GenerateSchema() ([]byte, error)
- func PrintSchema() error
- type CommandExecutor
- func (e *CommandExecutor) ListCustomCommands() error
- func (e *CommandExecutor) ListKeysCommand() error
- func (e *CommandExecutor) ListMouseButtonsCommand() error
- func (e *CommandExecutor) RunCustomCommand(name, request string) error
- func (e *CommandExecutor) RunGetMousePositionCommand() error
- func (e *CommandExecutor) RunGetWheelPositionCommand() error
- func (e *CommandExecutor) RunInputCommand(key, action string, durationTicks int64, async bool) error
- func (e *CommandExecutor) RunMouseCommand(action string, x, y int, button string, durationTicks int64, async bool) error
- func (e *CommandExecutor) RunPingCommand() error
- func (e *CommandExecutor) RunScreenshotCommand(output string, b64 bool, async bool) error
- func (e *CommandExecutor) RunScriptCommand(input string, isFile bool) error
- func (e *CommandExecutor) RunVersionCommand() error
- func (e *CommandExecutor) RunWheelCommand(x, y float64, async bool) error
- type Writer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EnsureTargetPID ¶
func EnsureTargetPID() error
EnsureTargetPID auto-detects the game PID if not already set.
func GenerateSchema ¶ added in v0.3.0
GenerateSchema generates a JSON Schema from the Go structs.
func PrintSchema ¶ added in v0.3.0
func PrintSchema() error
PrintSchema prints the JSON schema to stdout.
Types ¶
type CommandExecutor ¶
type CommandExecutor struct {
// contains filtered or unexported fields
}
CommandExecutor executes CLI commands via RPC.
func NewCommandExecutor ¶
func NewCommandExecutor() *CommandExecutor
NewCommandExecutor creates a new CommandExecutor.
func (*CommandExecutor) ListCustomCommands ¶ added in v0.3.0
func (e *CommandExecutor) ListCustomCommands() error
ListCustomCommands lists all registered custom commands.
func (*CommandExecutor) ListKeysCommand ¶
func (e *CommandExecutor) ListKeysCommand() error
ListKeysCommand lists all available key names.
func (*CommandExecutor) ListMouseButtonsCommand ¶
func (e *CommandExecutor) ListMouseButtonsCommand() error
ListMouseButtonsCommand lists all available mouse button names.
func (*CommandExecutor) RunCustomCommand ¶ added in v0.3.0
func (e *CommandExecutor) RunCustomCommand(name, request string) error
RunCustomCommand runs a custom command.
func (*CommandExecutor) RunGetMousePositionCommand ¶ added in v0.3.0
func (e *CommandExecutor) RunGetMousePositionCommand() error
RunGetMousePositionCommand runs a get_mouse_position command.
func (*CommandExecutor) RunGetWheelPositionCommand ¶ added in v0.3.0
func (e *CommandExecutor) RunGetWheelPositionCommand() error
RunGetWheelPositionCommand runs a get_wheel_position command.
func (*CommandExecutor) RunInputCommand ¶
func (e *CommandExecutor) RunInputCommand(key, action string, durationTicks int64, async bool) error
RunInputCommand runs an input command.
func (*CommandExecutor) RunMouseCommand ¶
func (e *CommandExecutor) RunMouseCommand(action string, x, y int, button string, durationTicks int64, async bool) error
RunMouseCommand runs a mouse command.
func (*CommandExecutor) RunPingCommand ¶
func (e *CommandExecutor) RunPingCommand() error
RunPingCommand runs a ping command to check connection.
func (*CommandExecutor) RunScreenshotCommand ¶
func (e *CommandExecutor) RunScreenshotCommand(output string, b64 bool, async bool) error
RunScreenshotCommand runs a screenshot command.
func (*CommandExecutor) RunScriptCommand ¶
func (e *CommandExecutor) RunScriptCommand(input string, isFile bool) error
RunScriptCommand runs a script from a file path or inline JSON string.
func (*CommandExecutor) RunVersionCommand ¶ added in v0.4.0
func (e *CommandExecutor) RunVersionCommand() error
RunVersionCommand runs the version command. Shows CLI version and attempts to get game version via ping.
func (*CommandExecutor) RunWheelCommand ¶
func (e *CommandExecutor) RunWheelCommand(x, y float64, async bool) error
RunWheelCommand runs a wheel command.